yakumo.cinder.v2

Package yakumo :: Package cinder :: Package v2 |
[hide private]
[frames] | no frames]

# Source Code for Package yakumo.cinder.v2

     1  # Copyright 2014-2017 by Akira Yoshiyama <akirayoshiyama@gmail.com>.
     2  # All Rights Reserved.
     3  #
     4  #    Licensed under the Apache License, Version 2.0 (the "License"); you may
     5  #    not use this file except in compliance with the License. You may obtain
     6  #    a copy of the License at
     7  #
     8  #         http://www.apache.org/licenses/LICENSE-2.0
     9  #
    10  #    Unless required by applicable law or agreed to in writing, software
    11  #    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
    12  #    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
    13  #    License for the specific language governing permissions and limitations
    14  #    under the License.
    15
    16  """
    17  Sub client class for Cinder API V2
    18  """
    19
    20  from . import consistency_group
    21  from . import consistency_group_snapshot
    22  from . import qos
    23  from . import quota_set
    24  from . import service
    25  from . import snapshot
    26  from . import volume
    27  from . import volume_backup
    28  from . import volume_transfer
    29  from . import volume_type
    30
    31
    32 -class Client(object):
    33
    34 -    def __init__(self, client, **kwargs):
    35          self.consistency_group = consistency_group.Manager(client, **kwargs)
    36          self.consistency_group_snapshot = \
    37              consistency_group_snapshot.Manager(client, **kwargs)
    38          self.quota_set = quota_set.Manager(client, **kwargs)
    39          self.service = service.Manager(client, **kwargs)
    40          self.volume = volume.Manager(client, **kwargs)
    41          self.volume_backup = volume_backup.Manager(client, **kwargs)
    42          self.volume_snapshot = snapshot.Manager(client, **kwargs)
    43          self.volume_transfer = volume_transfer.Manager(client, **kwargs)
    44          self.volume_type = volume_type.Manager(client, **kwargs)
    45          self.volume_type_qos = qos.Manager(client, **kwargs)
    46
    47          client.consistency_group = self.consistency_group
    48          client.consistency_group_snapshot = self.consistency_group_snapshot
    49          client.volume = self.volume
    50          client.volume_backup = self.volume_backup
    51          client.volume_snapshot = self.volume_snapshot
    52          client.volume_transfer = self.volume_transfer
    53          client.volume_type = self.volume_type
    54          client.volume_type_qos = self.volume_type_qos
    55